@@ -82,7 +82,7 @@ Add_dialog_data *xa_create_add_dialog()
 	dialog_vbox1 = gtk_dialog_get_content_area(GTK_DIALOG(add_dialog->dialog1));
 
 	add_dialog->notebook1 = gtk_notebook_new ();
-	gtk_box_pack_start(GTK_BOX(dialog_vbox1), add_dialog->notebook1, TRUE, TRUE, 0);
+	gtk_container_add(GTK_CONTAINER(dialog_vbox1), add_dialog->notebook1);
 	gtk_container_set_border_width (GTK_CONTAINER (add_dialog->notebook1),4);
 
 	/* Selection page */
@@ -177,7 +177,7 @@ Add_dialog_data *xa_create_add_dialog()
 	gtk_box_pack_start (GTK_BOX (hbox3), frame2, TRUE, TRUE, 0);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame2), GTK_SHADOW_OUT);
 
-	add_dialog->alignment2 = gtk_alignment_new (0.5, 0.5, 1, 1);
+	add_dialog->alignment2 = gtk_alignment_new(0.5, 0.5, 1, 0);
 	gtk_container_add (GTK_CONTAINER (frame2), add_dialog->alignment2);
 	gtk_alignment_set_padding (GTK_ALIGNMENT (add_dialog->alignment2), 0, 0, 5, 5);
 
@@ -188,7 +188,7 @@ Add_dialog_data *xa_create_add_dialog()
 	gtk_box_pack_start (GTK_BOX (hbox3), frame3, TRUE, TRUE, 0);
 	gtk_frame_set_shadow_type (GTK_FRAME (frame3), GTK_SHADOW_OUT);
 
-	alignment3 = gtk_alignment_new (0.5, 0.5, 1, 1);
+	alignment3 = gtk_alignment_new(0.5, 0.5, 1, 0);
 	gtk_container_add (GTK_CONTAINER (frame3), alignment3);
 	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment3), 0, 0, 5, 5);
 
@@ -471,8 +471,7 @@ void xa_execute_add_commands (XArchive *archive, GSList *list, gboolean recurse,
 		list = list->next;
 	}
 	files = xa_collect_filenames(archive, dirlist);
-	g_slist_foreach(dirlist,(GFunc)g_free,NULL);
-	g_slist_free(dirlist);
+	g_slist_free_full(dirlist, g_free);
 
 	archive->status = XARCHIVESTATUS_ADD;
 	(*archive->archiver->add)(archive, files, compression);
