@@ -411,8 +411,7 @@ void xa_spawn_async_process (XArchive *archive, const gchar *command)
 
 	if (archive->output)
 	{
-		g_slist_foreach(archive->output, (GFunc) g_free, NULL);
-		g_slist_free(archive->output);
+		g_slist_free_full(archive->output, g_free);
 		archive->output = NULL;
 	}
 
@@ -469,10 +468,7 @@ void xa_clean_archive_structure (XArchive *archive)
 		g_string_free(archive->comment, TRUE);
 
 	if (archive->output)
-	{
-		g_slist_foreach(archive->output, (GFunc) g_free, NULL);
-		g_slist_free(archive->output);
-	}
+		g_slist_free_full(archive->output, g_free);
 
 	if (archive->clipboard)
 		xa_clipboard_clear(NULL, archive);
@@ -763,7 +759,10 @@ gchar *xa_build_full_path_name_from_entry (XEntry *entry)
 		entry = entry->prev;
 	}
 
-	path_local = g_filename_from_utf8(path->str, -1, NULL, NULL, NULL);
+	if (g_utf8_validate(path->str, -1, NULL))
+		path_local = g_filename_from_utf8(path->str, -1, NULL, NULL, NULL);
+	else
+		path_local = g_strdup(path->str);
 
 	g_string_free(path, TRUE);
 
