@@ -19,18 +19,14 @@
 #ifndef ARJ_H
 #define ARJ_H
 
-#include <gtk/gtk.h>
-#include <string.h>
-#include <stdlib.h>
-#include "string_utils.h"
-#include "support.h"
+#include <glib.h>
 #include "archive.h"
-gboolean jump_header, encrypted, last_line;
-unsigned short int arj_line;
-void xa_arj_delete (XArchive *,GSList *);
-void xa_arj_add (XArchive *,GString *,gchar *);
-gboolean xa_arj_extract(XArchive *,GSList *);
-void xa_arj_test (XArchive *);
-void xa_get_arj_line_content (gchar *line, gpointer data);
-void xa_open_arj (XArchive *archive);
+
+void xa_arj_add(XArchive *, GSList *, gchar *);
+void xa_arj_ask(XArchive *);
+void xa_arj_delete(XArchive *, GSList *);
+gboolean xa_arj_extract(XArchive *, GSList *);
+void xa_arj_list(XArchive *);
+void xa_arj_test(XArchive *);
+
 #endif
