@@ -20,8 +20,11 @@
 #ifndef DEB_H
 #define DEB_H
 
-#include "callbacks.h"
+#include <glib.h>
 #include "archive.h"
 
-void OpenDeb ( XArchive *archive );
+void xa_deb_ask(XArchive *);
+gboolean xa_deb_extract(XArchive *, GSList *);
+void xa_deb_list(XArchive *);
+
 #endif
