@@ -200,8 +200,7 @@ static void xa_multi_extract_dialog_remove_files (GtkButton *button, Multi_extra
 	}
 	if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model),&iter)== FALSE)
 		gtk_widget_set_sensitive(GTK_WIDGET(button), FALSE);
-	g_list_foreach(rr_list,(GFunc)gtk_tree_row_reference_free,NULL);
-	g_list_free(rr_list);
+	g_list_free_full(rr_list, (GDestroyNotify) gtk_tree_row_reference_free);
 }
 
 static gchar *xa_multi_extract_one_archive (Multi_extract_data *dialog, gchar *filename, gboolean overwrite, gboolean full_path, gchar *dest_path)
@@ -304,7 +303,7 @@ Extract_dialog_data *xa_create_extract_dialog()
 	dialog_data->dialog_vbox1 = gtk_dialog_get_content_area(GTK_DIALOG(dialog_data->dialog1));
 
 	vbox1 = gtk_vbox_new (FALSE,2);
-	gtk_box_pack_start (GTK_BOX (dialog_data->dialog_vbox1),vbox1,TRUE,TRUE,0);
+	gtk_container_add(GTK_CONTAINER(dialog_data->dialog_vbox1), vbox1);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1),2);
 
 	label1 = gtk_label_new (_("Extract to:"));
@@ -335,7 +334,7 @@ Extract_dialog_data *xa_create_extract_dialog()
 
 	alignment1 = gtk_alignment_new (0.5,0.5,1,1);
 	gtk_container_add (GTK_CONTAINER (frame1),alignment1);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment1),0,0,12,0);
+	gtk_alignment_set_padding(GTK_ALIGNMENT(alignment1), 0, 2, 12, 0);
 
 	vbox3 = gtk_vbox_new (FALSE,0);
 	gtk_container_add (GTK_CONTAINER (alignment1),vbox3);
@@ -370,7 +369,7 @@ Extract_dialog_data *xa_create_extract_dialog()
 
 	alignment2 = gtk_alignment_new (0.5,0.5,1,1);
 	gtk_container_add (GTK_CONTAINER (frame2),alignment2);
-	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment2),0,0,12,0);
+	gtk_alignment_set_padding(GTK_ALIGNMENT(alignment2), 0, 4, 12, 0);
 
 	vbox5 = gtk_vbox_new (FALSE,0);
 	gtk_container_add (GTK_CONTAINER (alignment2),vbox5);
