@@ -91,7 +91,7 @@ static GtkWidget *properties;
 static GtkWidget *red_led;
 static GtkWidget *save1;
 static GtkWidget *select_pattern;
-static gulong selchghid;
+static gulong changed;
 
 static const GtkTargetEntry drag_targets[] =
 {
@@ -292,12 +292,9 @@ static void xa_dir_sidebar_drag_data_received (GtkWidget *widget, GdkDragContext
 	archive[idx]->do_full_path = full_path;
 
 	g_string_free(full_pathname,TRUE);
-	if (list != NULL)
-	{
-		g_slist_foreach(list,(GFunc) g_free,NULL);
-		g_slist_free(list);
-	}
+	g_slist_free_full(list, g_free);
 	g_strfreev (array);
+
 	gtk_drag_finish (context,TRUE,FALSE,time);
 }
 
@@ -397,8 +394,7 @@ static void xa_page_has_changed (GtkNotebook *notebook, GTK_COMPAT_SWITCH_PAGE_T
 		else
 			gtk_entry_set_text(GTK_ENTRY(location_entry),"\0");
 
-		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(archive_dir_treeview));
-		g_signal_handler_block(selection, selchghid);
+		xa_block_signal_dir_treeview_selection(TRUE);
 
 		xa_fill_dir_sidebar(archive[id],TRUE);
 		gtk_widget_grab_focus(archive_dir_treeview);
@@ -408,7 +404,7 @@ static void xa_page_has_changed (GtkNotebook *notebook, GTK_COMPAT_SWITCH_PAGE_T
 		else
 			gtk_tree_selection_unselect_all(gtk_tree_view_get_selection(GTK_TREE_VIEW(archive_dir_treeview)));
 
-		g_signal_handler_unblock(selection, selchghid);
+		xa_block_signal_dir_treeview_selection(FALSE);
 	}
 	xa_set_button_state(1, 1, 1, 1, archive[id]->can_test, 1, archive[id]->can_add, archive[id]->can_extract, archive[id]->sorted, archive[id]->can_sfx, archive[id]->has_comment, archive[id]->output, archive[id]->has_password);
 }
@@ -443,7 +439,7 @@ static void xa_select_by_pattern_dialog (GtkMenuItem *menuitem, gpointer user_da
 
 	dhbox1 = gtk_hbox_new (FALSE,10);
 	gtk_widget_show (dhbox1);
-	gtk_box_pack_start (GTK_BOX (ddialog_vbox1),dhbox1,TRUE,TRUE,0);
+	gtk_container_add(GTK_CONTAINER(ddialog_vbox1), dhbox1);
 	gtk_container_set_border_width (GTK_CONTAINER (dhbox1),5);
 
 	pattern_label = gtk_label_new (_("Pattern:"));
@@ -642,7 +638,7 @@ void xa_create_main_window (GtkWidget *xa_main_window, gboolean show_location, g
 	xa_set_window_title (xa_main_window,NULL);
 
 	//g_signal_connect (G_OBJECT (icon_theme),"changed",G_CALLBACK (xa_icon_theme_changed),NULL);
-	icon = gtk_icon_theme_load_icon(icon_theme,"xarchiver",24,0,NULL);
+	icon = gtk_icon_theme_load_icon(icon_theme, "xarchiver", 24, (GtkIconLookupFlags) 0, NULL);
 	gtk_window_set_icon (GTK_WINDOW(xa_main_window),icon);
 	g_signal_connect (G_OBJECT (xa_main_window),"delete-event",G_CALLBACK (xa_quit_application),NULL);
 
@@ -770,7 +766,7 @@ void xa_create_main_window (GtkWidget *xa_main_window, gboolean show_location, g
 	gtk_widget_set_sensitive (delete_menu,FALSE);
 	gtk_widget_show (delete_menu);
 	gtk_container_add (GTK_CONTAINER (menuitem2_menu),delete_menu);
-	gtk_widget_add_accelerator(delete_menu, "activate", accel_group, GDK_KEY_Delete, 0, GTK_ACCEL_VISIBLE);
+	gtk_widget_add_accelerator(delete_menu, "activate", accel_group, GDK_KEY_Delete, (GdkModifierType) 0, GTK_ACCEL_VISIBLE);
 
 	rename_menu = gtk_image_menu_item_new_with_mnemonic (_("Re_name"));
 	gtk_widget_set_sensitive (rename_menu,FALSE);
@@ -895,7 +891,7 @@ void xa_create_main_window (GtkWidget *xa_main_window, gboolean show_location, g
 	help1 = gtk_image_menu_item_new_with_mnemonic (_("_Contents"));
 	gtk_widget_show (help1);
 	gtk_container_add (GTK_CONTAINER (menuitem4_menu),help1);
-	gtk_widget_add_accelerator(help1, "activate", accel_group, GDK_KEY_F1, 0, GTK_ACCEL_VISIBLE);
+	gtk_widget_add_accelerator(help1, "activate", accel_group, GDK_KEY_F1, (GdkModifierType) 0, GTK_ACCEL_VISIBLE);
 
 	tmp_image = gtk_image_new_from_stock ("gtk-help",GTK_ICON_SIZE_MENU);
 	gtk_widget_show (tmp_image);
@@ -1048,7 +1044,7 @@ void xa_create_main_window (GtkWidget *xa_main_window, gboolean show_location, g
 	g_signal_connect(G_OBJECT(archive_dir_treeview), "drag-data-received", G_CALLBACK(xa_dir_sidebar_drag_data_received), NULL);
 	g_signal_connect(G_OBJECT(archive_dir_treeview), "drag-motion", G_CALLBACK(xa_dir_sidebar_drag_motion), NULL);
 	GtkTreeSelection *sel = gtk_tree_view_get_selection(GTK_TREE_VIEW (archive_dir_treeview));
-	selchghid = g_signal_connect(G_OBJECT(sel), "changed", G_CALLBACK(xa_dir_sidebar_row_selected), NULL);
+	changed = g_signal_connect(G_OBJECT(sel), "changed", G_CALLBACK(xa_dir_sidebar_row_selected), NULL);
 
 	column = gtk_tree_view_column_new();
 	archive_dir_renderer = gtk_cell_renderer_pixbuf_new();
@@ -1395,143 +1391,124 @@ GtkWidget *xa_create_archive_properties_window()
 	name_label = gtk_label_new ("");
 	set_label ( name_label,_("Name:"));
 	gtk_table_attach (GTK_TABLE (table1),name_label,0,1,0,1,
-                     (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (name_label),1,0.5);
 
 	path_label = gtk_label_new ("");
 	set_label ( path_label,_("Path:"));
 	gtk_table_attach (GTK_TABLE (table1),path_label,0,1,1,2,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (path_label),1,0.5);
 
 	type_label = gtk_label_new ("");
 	set_label ( type_label,_("Type:"));
 	gtk_table_attach (GTK_TABLE (table1),type_label,0,1,2,3,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (type_label),1,0.5);
 
 	encrypted_label = gtk_label_new ("");
 	set_label ( encrypted_label,_("Encrypted:"));
 	gtk_table_attach (GTK_TABLE (table1),encrypted_label,0,1,3,4,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (encrypted_label),0.99,0.5);
 
 	modified_label = gtk_label_new ("");
 	set_label ( modified_label,_("Modified on:"));
 	gtk_table_attach (GTK_TABLE (table1),modified_label,0,1,4,5,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (modified_label),1,0.5);
 
 	size_label = gtk_label_new ("");
 	set_label ( size_label,_("Compressed size:"));
 	gtk_table_attach (GTK_TABLE (table1),size_label,0,1,5,6,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (size_label),0.99,0.5);
 
 	content_label = gtk_label_new ("");
 	set_label ( content_label,_("Uncompressed size:"));
 	gtk_table_attach (GTK_TABLE (table1),content_label,0,1,6,7,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (content_label),0.99,0.5);
 
 	comment_label = gtk_label_new ("");
 	set_label ( comment_label,_("Comment:"));
 	gtk_table_attach (GTK_TABLE (table1),comment_label,0,1,7,8,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (comment_label),0.99,0.5);
 
 	number_of_files_label = gtk_label_new ("");
 	set_label ( number_of_files_label,_("Number of files:"));
 	gtk_table_attach (GTK_TABLE (table1),number_of_files_label,0,1,8,9,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (number_of_files_label),0.99,0.5);
 
 	compression_label = gtk_label_new ("");
 	set_label ( compression_label,_("Compression ratio:"));
 	gtk_table_attach (GTK_TABLE (table1),compression_label,0,1,9,10,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 	gtk_misc_set_alignment (GTK_MISC (compression_label),0.99,0.5);
 
 	archiver_label = gtk_label_new("");
 	set_label(archiver_label, _("Archiver executable:"));
-	gtk_table_attach(GTK_TABLE(table1), archiver_label, 0, 1, 10, 11, GTK_FILL, 0, 0, 0);
+	gtk_table_attach(GTK_TABLE(table1), archiver_label, 0, 1, 10, 11, GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 	gtk_misc_set_alignment(GTK_MISC(archiver_label), 0.99, 0.5);
 
 /* */
 
 	archiver_data = gtk_label_new("");
 	gtk_misc_set_alignment(GTK_MISC(archiver_data), 0, 0.5);
-	gtk_table_attach(GTK_TABLE(table1), archiver_data, 1, 2, 10, 11, GTK_FILL, 0, 0, 0);
+	gtk_table_attach(GTK_TABLE(table1), archiver_data, 1, 2, 10, 11, GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 
 	compression_data = gtk_label_new("");
 	gtk_misc_set_alignment (GTK_MISC (compression_data),0,0.5);
 	gtk_table_attach (GTK_TABLE (table1),compression_data,1,2,9,10,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 
 	number_of_files_data = gtk_label_new("");
 	gtk_misc_set_alignment (GTK_MISC (number_of_files_data),0,0.5);
 	gtk_table_attach (GTK_TABLE (table1),number_of_files_data,1,2,8,9,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 
 	comment_data = gtk_label_new("");
 	gtk_misc_set_alignment (GTK_MISC (comment_data),0,0.5);
 	gtk_table_attach (GTK_TABLE (table1),comment_data,1,2,7,8,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 
 	content_data = gtk_label_new("");
 	gtk_misc_set_alignment (GTK_MISC (content_data),0,0.5);
 	gtk_table_attach (GTK_TABLE (table1),content_data,1,2,6,7,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 
 	size_data = gtk_label_new("");
 	gtk_misc_set_alignment (GTK_MISC (size_data),0,0.5);
 	gtk_table_attach (GTK_TABLE (table1),size_data,1,2,5,6,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 
 	modified_data = gtk_label_new("");
 	gtk_misc_set_alignment (GTK_MISC (modified_data),0,0.5);
 	gtk_table_attach (GTK_TABLE (table1),modified_data,1,2,4,5,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 
 	encrypted_data = gtk_label_new("");
 	gtk_misc_set_alignment (GTK_MISC (encrypted_data),0,0.5);
 	gtk_table_attach (GTK_TABLE (table1),encrypted_data,1,2,3,4,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 
 	type_data = gtk_label_new("");
 	gtk_misc_set_alignment (GTK_MISC (type_data),0,0.5);
 	gtk_table_attach (GTK_TABLE (table1),type_data,1,2,2,3,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 
 	path_data = gtk_label_new("");
 	gtk_misc_set_alignment (GTK_MISC (path_data),0,0.5);
 	gtk_table_attach (GTK_TABLE (table1),path_data,1,2,1,2,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
 
 	name_data = gtk_label_new("");
 	gtk_misc_set_alignment (GTK_MISC (name_data),0,0.5);
 	gtk_table_attach (GTK_TABLE (table1),name_data,1,2,0,1,
-                    (GtkAttachOptions) (GTK_FILL),
-                    (GtkAttachOptions) (0),0,0);
+	                  GTK_FILL, (GtkAttachOptions) 0, 0, 0);
+
 	return archive_properties_window;
 }
 
@@ -1586,7 +1563,7 @@ void xa_show_progress_bar (XArchive *archive)
 	gtk_container_set_border_width(GTK_CONTAINER(progress->window), 6);
 	gtk_window_set_transient_for(GTK_WINDOW(progress->window), GTK_WINDOW(xa_main_window));
 
-	pixbuf = gtk_icon_theme_load_icon(icon_theme,"xarchiver",24,0,NULL);
+	pixbuf = gtk_icon_theme_load_icon(icon_theme, "xarchiver", 24, (GtkIconLookupFlags) 0, NULL);
 	gtk_window_set_icon(GTK_WINDOW(progress->window), pixbuf);
 	g_object_unref(pixbuf);
 
@@ -1597,7 +1574,7 @@ void xa_show_progress_bar (XArchive *archive)
 	hbox1 = gtk_hbox_new (FALSE,12);
 	gtk_box_pack_start (GTK_BOX (vbox1),hbox1,TRUE,TRUE,0);
 
-	pixbuf = gtk_icon_theme_load_icon(icon_theme,"gnome-mime-application-zip",40,0,NULL);
+	pixbuf = gtk_icon_theme_load_icon(icon_theme, "gnome-mime-application-zip", 40, (GtkIconLookupFlags) 0, NULL);
 	if (!pixbuf) pixbuf = gtk_icon_theme_load_icon(icon_theme,"package-x-generic",40,GTK_ICON_LOOKUP_FORCE_SIZE,NULL);
 	icon_pixbuf = gtk_image_new_from_pixbuf(pixbuf);
 	g_object_unref(pixbuf);
@@ -1740,3 +1717,15 @@ GSList *xa_file_filter_add_archiver_pattern_sort (GtkFileFilter *filter)
 
 	return sorted;
 }
+
+void xa_block_signal_dir_treeview_selection (gboolean block)
+{
+	GtkTreeSelection *selection;
+
+	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(archive_dir_treeview));
+
+	if (block)
+		g_signal_handler_block(selection, changed);
+	else
+		g_signal_handler_unblock(selection, changed);
+}
