@@ -1,7 +1,5 @@
 /*
- *  Xarchiver
- *
- *  Copyright (C) 2005 Giuseppe Torelli - Colossus
+ *  Copyright (C) 2008 Giuseppe Torelli - <colossus73@gmail.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,23 +15,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  */
- 
+
 #ifndef RPM_H
 #define RPM_H
 
- #include <gtk/gtk.h>
- #include "callbacks.h"
- #include "interface.h"
- #include "support.h"
- #include "main.h"
+#include <glib.h>
+#include "archive.h"
 
-void OpenRPM ( gboolean mode , gchar *path );
-GChildWatchFunc *DecompressCPIO (GPid pid , gint status , gpointer data);
-GChildWatchFunc *OpenCPIO (GPid pid , gint status , gpointer data);
-
-void SpawnCPIO ( gchar *command , gchar* tmp , gboolean add_flag , gboolean input_flag );
-gboolean ReadCPIOOutput (GIOChannel *ioc, GIOCondition cond, gpointer data);
-gboolean WriteCPIOInput (GIOChannel *ioc, GIOCondition cond, gpointer data);
-void CloseChannels ( GIOChannel *ioc );
+void xa_rpm_ask(XArchive *);
+gboolean xa_rpm_extract(XArchive *, GSList *);
+void xa_rpm_list(XArchive *);
 
 #endif
