@@ -41,6 +41,11 @@
 
 /* GLib compatibility */
 
+#if !GLIB_CHECK_VERSION(2,28,0)
+#define g_list_free_full(list, free_func) do { g_list_foreach(list, (GFunc) free_func, NULL); g_list_free(list); } while (0)
+#define g_slist_free_full(list, free_func) do { g_slist_foreach(list, (GFunc) free_func, NULL); g_slist_free(list); } while (0)
+#endif
+
 #if !GLIB_CHECK_VERSION(2,30,0)
 #include "string_utils.h"
 #define g_mkdtemp(tmpl) mkdtemp(tmpl)
