@@ -19,22 +19,15 @@
 #ifndef TAR_H
 #define TAR_H
 
-#include <gtk/gtk.h>
-#include <stdlib.h>
-#include <unistd.h>
-#include "string_utils.h"
-#include "support.h"
+#include <glib.h>
+#include <stdio.h>
 #include "archive.h"
-#include "gzip.h"
 
-void xa_open_tar ( XArchive * );
-void xa_tar_delete (XArchive *,GSList *);
-void xa_tar_add (XArchive *,GString *,gchar *);
-gboolean xa_tar_extract(XArchive *,GSList *);
-void xa_get_tar_line_content (gchar *, gpointer );
-gboolean isTar (FILE *);
-gboolean is_tar_compressed (gint );
-void xa_add_delete_bzip2_gzip_lzma_compressed_tar (GString *,XArchive *,gboolean );
-gboolean xa_extract_tar_without_directories ( gchar *, XArchive *,gchar *);
+gboolean isTar(FILE *);
+void xa_tar_add(XArchive *, GSList *, gchar *);
+void xa_tar_ask(XArchive *);
+void xa_tar_delete(XArchive *, GSList *);
+gboolean xa_tar_extract(XArchive *, GSList *);
+void xa_tar_list(XArchive *);
+
 #endif
-
