@@ -373,7 +373,7 @@ static void xa_activate_link (GtkAboutDialog *about, const gchar *link, gpointer
 static void xa_rename_cell_edited_canceled (GtkCellRenderer *renderer, gpointer user_data)
 {
 	g_object_set(renderer,"editable",FALSE,NULL);
-	gtk_widget_add_accelerator(delete_menu, "activate", accel_group, GDK_KEY_Delete, 0, GTK_ACCEL_VISIBLE);
+	gtk_widget_add_accelerator(delete_menu, "activate", accel_group, GDK_KEY_Delete, (GdkModifierType) 0, GTK_ACCEL_VISIBLE);
 }
 
 static void xa_rename_cell_edited (GtkCellRendererText *cell, const gchar *path_string, const gchar *new_name, XArchive *archive)
@@ -803,7 +803,9 @@ void xa_child_processed (XAChildProcess process, gboolean success, XArchive *arc
 			{
 				if (archive->parse_output)
 				{
+					xa_block_signal_dir_treeview_selection(TRUE);
 					gtk_widget_grab_focus(archive_dir_treeview);
+					xa_block_signal_dir_treeview_selection(FALSE);
 					xa_update_window_with_archive_entries(archive, NULL);
 					xa_expand_containing_directory(archive);
 					gtk_tree_view_set_model(GTK_TREE_VIEW(archive->treeview), archive->model);
@@ -1818,6 +1820,8 @@ ArchiveType xa_detect_archive_type (const gchar *filename)
 
 		if (g_str_has_suffix(filename, ".apk"))
 			xa.tag = 'a';
+		else if (g_str_has_suffix(filename, ".cbz"))
+			xa.tag = 'c';
 		else if (g_str_has_suffix(filename, ".epub"))
 			xa.tag = 'e';
 		else if (g_str_has_suffix(filename, ".jar"))
@@ -1979,7 +1983,7 @@ void xa_archive_properties (GtkMenuItem *menuitem,gpointer user_data)
 	g_free(t);
     /* Modified Date */
     strftime (date,64,"%c",localtime (&my_stat.st_mtime));
-    t = g_locale_to_utf8 (date,-1,0,0,0);
+    t = g_locale_to_utf8(date, -1, NULL, NULL, NULL);
     gtk_label_set_text(GTK_LABEL(modified_data),t);
     g_free (t);
     /* Archive Size */
@@ -2125,8 +2129,7 @@ void drag_begin (GtkWidget *widget, GdkDragContext *context, XArchive *archive)
 					(guchar *) XDS_FILENAME,
 			     	strlen (XDS_FILENAME));
 
-	g_list_foreach (row_list,(GFunc) gtk_tree_path_free,NULL);
-	g_list_free (row_list);
+	g_list_free_full(row_list, (GDestroyNotify) gtk_tree_path_free);
 }
 
 void drag_data_get (GtkWidget *widget, GdkDragContext *context, GtkSelectionData *data, guint info, guint time, XArchive *archive)
@@ -2147,8 +2150,7 @@ void drag_data_get (GtkWidget *widget, GdkDragContext *context, GtkSelectionData
 	if (row_list == NULL)
 		return;
 
-	g_list_foreach(row_list, (GFunc) gtk_tree_path_free, NULL);
-	g_list_free(row_list);
+	g_list_free_full(row_list, (GDestroyNotify) gtk_tree_path_free);
 
 	gdk_property_get(gdk_drag_context_get_source_window(context),
 	                 gdk_atom_intern("XdndDirectSave0", FALSE),
@@ -2643,8 +2645,7 @@ void xa_clipboard_clear (GtkClipboard *clipboard, XArchive *archive)
 	{
 		if (archive->clipboard->files != NULL)
 		{
-			g_slist_foreach(archive->clipboard->files, (GFunc) g_free, NULL);
-			g_slist_free(archive->clipboard->files);
+			g_slist_free_full(archive->clipboard->files, g_free);
 			archive->clipboard->files = NULL;
 		}
 
@@ -2668,7 +2669,7 @@ void xa_rename_archive (GtkMenuItem *item, gpointer user_data)
 	row_list = gtk_tree_selection_get_selected_rows(selection,&model);
 
 	g_object_set(archive[idx]->text_renderer, "editable", TRUE, NULL);
-	gtk_widget_remove_accelerator(delete_menu, accel_group, GDK_KEY_Delete, 0);
+	gtk_widget_remove_accelerator(delete_menu, accel_group, GDK_KEY_Delete, (GdkModifierType) 0);
 	column = gtk_tree_view_get_column(GTK_TREE_VIEW (archive[idx]->treeview),0);
 	gtk_tree_view_set_cursor(GTK_TREE_VIEW(archive[idx]->treeview),row_list->data,column,TRUE);
 	gtk_tree_path_free (row_list->data);
@@ -2736,8 +2737,7 @@ void xa_open_with_from_popupmenu (GtkMenuItem *item, gpointer user_data)
 	while (list_of_files);
 	xa_create_open_with_dialog(entry->filename,names->str,nr);
 	g_string_free(names, FALSE);
-	g_slist_foreach(list_of_files,(GFunc)g_free,NULL);
-	g_slist_free(list_of_files);
+	g_slist_free_full(list_of_files, g_free);
 }
 
 void xa_view_from_popupmenu (GtkMenuItem *item, gpointer user_data)
@@ -2988,7 +2988,7 @@ GtkWidget *xa_main_window_find_image (gchar *filename, GtkIconSize size)
   if (ext)
   {
     *ext = 0;
-    file_pixbuf = gtk_icon_theme_load_icon(icon_theme, name, size, 0, NULL);
+    file_pixbuf = gtk_icon_theme_load_icon(icon_theme, name, size, (GtkIconLookupFlags) 0, NULL);
   }
 
   g_free(name);
